<?php

namespace Drupal\drush_endpoint\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Site\Settings;

#[\Attribute]
final class DrushEndpointAccessChecker {
  private const ALLOWED_COMMANDS = [
    // Consider making those configurable via a form
    'cr',
    'cron',
    'uli', // Will only work if allowed in settings file
    'mim',
    'mr',
    'sapi-i',
    'sapi-r'
  ];

  public function access(AccountInterface $account, ?string $command = null): AccessResultInterface {
    // Check if the module is allowed to run
    if (!\Drupal::hasContainer() ||
      !Settings::get('drush_endpoint_enabled', false)) {
      return AccessResult::forbidden('Drush endpoint is not enabled in settings.php');
    }
    if ($command === 'uli') {
      if (!\Drupal::hasContainer() ||
        !Settings::get('drush_endpoint_allow_uli', false)) {
        return AccessResult::forbidden('ULI is not allowed in settings.php');
      }
    }

    if (!in_array($command, self::ALLOWED_COMMANDS, true)) {
      return AccessResult::forbidden('Command not in allowed list');
    }

    return AccessResult::allowed();
  }
}
