<?php

namespace Drupal\drush_endpoint\Service;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\Process\Exception\ProcessFailedException;
use Symfony\Component\Process\Process;

#[\Attribute]
final class DrushExecutor {
  private readonly LoggerInterface $logger;

  public function __construct(
    LoggerChannelFactoryInterface $logger_factory,
  ) {
    $this->logger = $logger_factory->get('drush_endpoint');
  }

  public function execute(string $command): array {
    // Split the command into arguments to safely handle it with Symfony Process
    $commandParts = explode(' ', $command);
    $process = new Process(['drush', ...$commandParts]);

    try {
      // Run the process
      $process->mustRun();

      $result = [
        'success' => true,
        'output' => $process->getOutput(),
        'command' => $command,
      ];

      // Log success
      $this->logger->info('Executed Drush command: @command successfully.', [
        '@command' => $command,
      ]);
    } catch (ProcessFailedException $e) {
      $result = [
        'success' => false,
        'output' => $process->getErrorOutput(),
        'command' => $command,
      ];

      // Log failure
      $this->logger->error('Failed to execute Drush command: @command. Error: @error', [
        '@command' => $command,
        '@error' => $e->getMessage(),
      ]);
    }

    return $result;
  }
}
